timeseries.test\_mollifier.TestMollifier
========================================

.. currentmodule:: timeseries.test_mollifier

.. autoclass:: TestMollifier

   

      .. autosummary::
         :toctree:
      
         TestMollifier.setup
         TestMollifier.setup_method
         TestMollifier.teardown
         TestMollifier.teardown_method
         TestMollifier.test_refinement_counts
         TestMollifier.test_resonable_reconstruction



   

